Count the number of species observed the same number of times.
abd_freq_count(
abd,
level = NULL,
probability_estimator = c("Chao2015", "Chao2013", "ChaoShen", "naive"),
unveiling = c("geometric", "uniform", "none"),
richness_estimator = c("jackknife", "iChao1", "Chao1", "rarefy", "naive"),
jack_alpha = 0.05,
jack_max = 10,
coverage_estimator = c("ZhangHuang", "Chao", "Turing", "Good"),
check_arguments = TRUE
)A two-column tibble. The first column contains the number of observations, the second one the number of species observed this number of times.
A numeric vector containing species abundances.
the level of interpolation or extrapolation.
If NULL (by default), observed data is simply used
and all other arguments are ignored.
a string containing one of the possible estimators of the probability distribution (see probabilities). Used only for extrapolation.
a string containing one of the possible unveiling methods to estimate the probabilities of the unobserved species (see probabilities). Used only for extrapolation.
A string containing an estimator recognized by div_richness to evaluate the total number of species in probabilities. Used only for extrapolation.
the risk level, 5% by default, used to optimize the jackknife order.
the highest jackknife order allowed. Default is 10.
an estimator of sample coverage used by coverage.
if TRUE, the function arguments are verified.
Should be set to FALSE to save time when the arguments have been checked elsewhere.
The Abundance Frequency Count Chao2015divent is the number of species observed each number of times. It is a way to summarize the species distribution.
It can be estimated at a specified level of interpolation or extrapolation. Extrapolation relies on the estimation of the estimation of the asymptotic distribution of the community by probabilities and eq. (5) of Chao2014divent.
abd_freq_count(as.numeric(paracou_6_abd[1, ]))
Run the code above in your browser using DataLab