The typical use of this function is to define a narrow window around
a point pattern that has been created with a default, rectangle window.
The window is built by the alphahull::ashape() function and then transformed
into a spatstat.geom::owin.object.
The alpha parameter determines the smallest size of zones excluded from the window.
If it is not specified, a first attempt is 1/256 of the diameter of the existing window of X.
If the shape cannot be calculated, alpha is doubled and a new attempt is made.