Learn R Programming

divent (version 0.5-3)

ent_gen_simpson: Generalized Simpson's Entropy

Description

Estimate the Generalized Simpson's entropy of species from abundance or probability data.

Usage

ent_gen_simpson(x, ...)

# S3 method for numeric ent_gen_simpson( x, k = 1, estimator = c("Zhang", "naive"), as_numeric = FALSE, ..., check_arguments = TRUE )

# S3 method for species_distribution ent_gen_simpson( x, k = 1, estimator = c("Zhang", "naive"), gamma = FALSE, as_numeric = FALSE, ..., check_arguments = TRUE )

Value

A tibble with the site names, the estimators used and the estimated entropy.

Arguments

x

An object, that may be a numeric vector containing abundances or probabilities, or an object of class abundances or probabilities.

...

Unused.

k

the order of Hurlbert's diversity.

estimator

An estimator of entropy.

as_numeric

if TRUE, a number or a numeric vector is returned rather than a tibble.

check_arguments

if TRUE, the function arguments are verified. Should be set to FALSE to save time when the arguments have been checked elsewhere.

gamma

if TRUE, \(\gamma\) diversity, i.e. diversity of the metacommunity, is computed.

Details

The Generalized Simpson's Entropy Zhang2010divent of order \(k\) is, in the species accumulation curve,the probability for the individual sampled in rank \(k + 1\) to belong to a new species. It is a measure of diversity so long as \(k\) is lower than the number of species Grabchak2016divent.

Bias correction requires the number of individuals. It is limited to orders \(r\) less than or equal to the number of individuals in the community Zhang2014divent.

Generalized Simpson's diversity cannot be estimated at a specified level of interpolation or extrapolation, and diversity partitioning is not available.

See Also

div_gen_simpson

#' @references

Examples

Run this code
# Entropy of each community
ent_gen_simpson(paracou_6_abd, k = 50)
# gamma entropy
ent_gen_simpson(paracou_6_abd, k = 50, gamma = TRUE)

Run the code above in your browser using DataLab