Learn R Programming

divent (version 0.5-3)

ent_hurlbert: Hurlbert Entropy of a Community

Description

Estimate the Hurlbert entropy Hurlbert1971divent of species from abundance or probability data. Several estimators are available to deal with incomplete sampling.

Usage

ent_hurlbert(x, k = 2, ...)

# S3 method for numeric ent_hurlbert( x, k = 2, estimator = c("Hurlbert", "naive"), as_numeric = FALSE, ..., check_arguments = TRUE )

# S3 method for species_distribution ent_hurlbert( x, k = 2, estimator = c("Hurlbert", "naive"), as_numeric = FALSE, ..., check_arguments = TRUE )

Value

A tibble with the site names, the estimators used and the estimated entropy.

Arguments

x

An object, that may be a numeric vector containing abundances or probabilities, or an object of class abundances or probabilities.

k

the order of Hurlbert's diversity.

...

Unused.

estimator

An estimator of entropy.

as_numeric

if TRUE, a number or a numeric vector is returned rather than a tibble.

check_arguments

if TRUE, the function arguments are verified. Should be set to FALSE to save time when the arguments have been checked elsewhere.

Details

Bias correction requires the number of individuals. See div_hurlbert for estimators.

Hurlbert's entropy cannot be estimated at a specified level of interpolation or extrapolation, and entropy partitioning is not available.

References

See Also

div_hurlbert

Examples

Run this code
# Entropy of each community
ent_hurlbert(paracou_6_abd, k = 2)

Run the code above in your browser using DataLab