Learn R Programming

divent (version 0.5-3)

fun_similarity: Functional similarity

Description

Transform a distance matrix into a similarity matrix Leinster2012divent. Similarity between two species is defined either by a negative exponential function of their distance or by the complement to 1 of their normalized distance (such that the most distant species are 1 apart).

Usage

fun_similarity(distances, exponential = TRUE, rate = 1, check_arguments = TRUE)

Value

A similarity matrix.

Arguments

distances

a distance matrix or an object of class stats::dist.

exponential

If TRUE, similarity is \(e^{-r \delta}\), where \(r\) is argument rate. If FALSE, it is \(1 - \delta / \max(\delta)\).

rate

the decay rate of the exponential similarity.

check_arguments

if TRUE, the function arguments are verified. Should be set to FALSE to save time when the arguments have been checked elsewhere.

References

Examples

Run this code
# Similarity between Paracou 6 species
hist(fun_similarity(paracou_6_fundist))

Run the code above in your browser using DataLab