Learn R Programming

divent (version 0.5-3)

non_species_columns: Non-Species columns

Description

The column names that are not those of species in a species_distribution.

Usage

non_species_columns

Arguments

Format

A character vector.

Details

Objects of classes abundances and probabilities, that are also of class species_distribution, have columns named after the species they contain. Some columns are reserved to describe the plots and their diversity.