powered by
Utilities for community abundances (objects of class "abundances").
abd_species(abundances, check_arguments = TRUE)abd_sum(abundances, as_numeric = FALSE, check_arguments = TRUE)prob_species(species_distribution, check_arguments = TRUE)
abd_sum(abundances, as_numeric = FALSE, check_arguments = TRUE)
prob_species(species_distribution, check_arguments = TRUE)
abd_species() returns a tibble containing the species abundance columns only, to simplify numeric operations.
abd_species()
prob_species() returns the same tibble but values are probabilities.
prob_species()
abd_sum() returns the sample sizes of the communities in a numeric vector.
abd_sum()
an object of class abundances.
if TRUE, the function arguments are verified. Should be set to FALSE to save time when the arguments have been checked elsewhere.
TRUE
FALSE
if TRUE, a number or a numeric vector is returned rather than a tibble.
an object of class species_distribution.
abd_species(paracou_6_abd) prob_species(paracou_6_abd) abd_sum(paracou_6_abd)
Run the code above in your browser using DataLab