Estimate the diversity of species from abundance or probability data and a phylogenetic tree. Several estimators are available to deal with incomplete sampling.
div_phylo(x, tree, q = 1, ...)# S3 method for numeric
div_phylo(
x,
tree,
q = 1,
normalize = TRUE,
estimator = c("UnveilJ", "ChaoJost", "ChaoShen", "GenCov", "Grassberger", "Marcon",
"UnveilC", "UnveiliC", "ZhangGrabchak", "naive", "Bonachela", "Holste"),
level = NULL,
probability_estimator = c("Chao2015", "Chao2013", "ChaoShen", "naive"),
unveiling = c("geometric", "uniform", "none"),
richness_estimator = c("jackknife", "iChao1", "Chao1", "naive"),
jack_alpha = 0.05,
jack_max = 10,
coverage_estimator = c("ZhangHuang", "Chao", "Turing", "Good"),
as_numeric = FALSE,
...,
check_arguments = TRUE
)
# S3 method for species_distribution
div_phylo(
x,
tree,
q = 1,
normalize = TRUE,
estimator = c("UnveilJ", "ChaoJost", "ChaoShen", "GenCov", "Grassberger", "Marcon",
"UnveilC", "UnveiliC", "ZhangGrabchak", "naive", "Bonachela", "Holste"),
level = NULL,
probability_estimator = c("Chao2015", "Chao2013", "ChaoShen", "naive"),
unveiling = c("geometric", "uniform", "none"),
richness_estimator = c("jackknife", "iChao1", "Chao1", "naive"),
jack_alpha = 0.05,
jack_max = 10,
coverage_estimator = c("ZhangHuang", "Chao", "Turing", "Good"),
gamma = FALSE,
as_numeric = FALSE,
...,
check_arguments = TRUE
)
A tibble with the site names, the estimators used and the estimated diversity
An object, that may be a named numeric vector (names are species names) containing abundances or probabilities, or an object of class abundances or probabilities.
an ultrametric, phylogenetic tree. May be an object of class phylo_divent, ape::phylo, ade4::phylog or stats::hclust.
a number: the order of diversity.
Unused.
if TRUE, phylogenetic is normalized: the height of the tree is set to 1.
An estimator of asymptotic diversity.
the level of interpolation or extrapolation.
It may be a sample size (an integer) or a sample coverage
(a number between 0 and 1).
If not NULL, the asymptotic estimator is ignored.
a string containing one of the possible estimators of the probability distribution (see probabilities). Used only for extrapolation.
a string containing one of the possible unveiling methods to estimate the probabilities of the unobserved species (see probabilities). Used only for extrapolation.
an estimator of richness to evaluate the total number of species, see div_richness. used for interpolation and extrapolation.
the risk level, 5% by default, used to optimize the jackknife order.
the highest jackknife order allowed. Default is 10.
an estimator of sample coverage used by coverage.
if TRUE, a number or a numeric vector is returned rather than a tibble.
if TRUE, the function arguments are verified.
Should be set to FALSE to save time when the arguments have been checked elsewhere.
if TRUE, \(\gamma\) diversity, i.e. diversity of the metacommunity, is computed.
Bias correction requires the number of individuals. See div_hill for estimators.
Entropy can be estimated at a specified level of interpolation or extrapolation, either a chosen sample size or sample coverage Chao2014divent, rather than its asymptotic value. See accum_tsallis for details.
div_phylo(paracou_6_abd, tree = paracou_6_taxo, q = 2)
# At 80% coverage
div_phylo(paracou_6_abd, tree = paracou_6_taxo, q = 2, level = 0.8)
# Gamma entropy
div_phylo(paracou_6_abd, tree = paracou_6_taxo, q = 2, gamma = TRUE)
Run the code above in your browser using DataLab