Learn R Programming

divent (version 0.5-3)

fit_rac: Fit a distribution

Description

Fit a well-known distribution to a species distribution.

Usage

fit_rac(x, ...)

# S3 method for numeric fit_rac( x, distribution = c("lnorm", "lseries", "geom", "bstick"), ..., check_arguments = TRUE )

# S3 method for species_distribution fit_rac( x, distribution = c("lnorm", "lseries", "geom", "bstick"), ..., check_arguments = TRUE )

Value

A tibble with the sites and the estimated distribution parameters.

Arguments

x

An object

...

Unused.

distribution

The distribution of species abundances. May be "lnorm" (log-normal), "lseries" (log-series), "geom" (geometric) or "bstick" (broken stick).

check_arguments

if TRUE, the function arguments are verified. Should be set to FALSE to save time when the arguments have been checked elsewhere.

Details

abundances can be used to fit rank-abundance curves (RAC) of classical distributions:

  • "lnorm" for log-normal Preston1948divent.

  • "lseries" for log-series Fisher1943divent.

  • "geom" for geometric Motomura1932divent.

  • "bstick" for broken stick MacArthur1957divent. It has no parameter, so the maximum abundance is returned.

References

Examples

Run this code
fit_rac(paracou_6_abd, distribution = "lnorm")

Run the code above in your browser using DataLab